# -*- coding: utf-8 -*-
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2020 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT


# TODO: convert this file into python package
#       and move logic of modules manipulations here
import json
import os

from clwpos.utils import acquire_lock

ALLOWED_MODULES_CONFIG_VERSION = 1

# TODO: this part does not support shared environment
ALLOWED_MODULES_CONFIG = "/var/clwpos/solo/modules_allowed.json"


OBJECT_CACHE_MODULE = "object_cache"
ALL_OPTIMIZATION_MODULES = [
    OBJECT_CACHE_MODULE
]


def get_allowed_modules() -> list:
    """
    Reads configuration file (which is manipulated by admin)
    and returns only that modules which are allowed
    to be enabled by endusers.
    @return: list of module unique ids
    """
    if not os.path.exists(ALLOWED_MODULES_CONFIG):
        return ALL_OPTIMIZATION_MODULES

    # TODO: malformed config is breaking whole tool: LU-2647
    with open(ALLOWED_MODULES_CONFIG) as file:
        return [
            module
            for module, is_allowed in json.load(file)["modules"].items()
            if is_allowed
        ]


def get_all_modules_data(modules_json_path=ALLOWED_MODULES_CONFIG):
    """
    Reads modules statuses from .json or returns defaults
    """
    if not os.path.exists(modules_json_path):
        data = {
            "version": str(ALLOWED_MODULES_CONFIG_VERSION),
            "modules": dict.fromkeys(ALL_OPTIMIZATION_MODULES, True),
        }
        return data["modules"]
    with acquire_lock(modules_json_path):
        with open(modules_json_path, "r") as file:
            return json.load(file)["modules"]
